# eolearn.io subpackage

Input/output subpackage that deals with obtaining data from Sentinel Hub services or saving and loading data locally.

For more information on the package content, visit [readthedocs](https://eo-learn.readthedocs.io/en/latest/eolearn.io.html).
